@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2006 Zope Corporation and Contributors.
+# Copyright (c) 2006 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -24,6 +24,20 @@ class Index(grok.View):
     def render(self):
         self.redirect(self.url('home'))
 
+class Hello(grok.View):
+    grok.baseclass()
+    
+    def render(self):
+        return "Hello"
+
+class Hoi(Hello):
+    def render(self):
+        return "Hoi"
+
+class Bonjour(Hello):
+    def render(self):
+        return "Bonjour"
+
 @grok.subscribe(Wiki, grok.IObjectAddedEvent)
 def setupHomepage(wiki, event):
     """Creates a home page for every wiki."""
