@@ -1,11 +1,11 @@
 """
 If no model can be found in the module, we get an error:
 
-  >>> grok.grok(__name__)
+  >>> grok.testing.grok(__name__)
   Traceback (most recent call last):
     ...
   GrokError: No module-level context for
-  <class 'grok.tests.adapter.nomodel.Home'>, please use grok.context.
+  <class 'grok.tests.adapter.nomodel.Home'>, please use the 'context' directive.
 
 """
 import grok
