@@ -14,20 +14,22 @@
 """Grok utility functions.
 """
 import grok
-import grok.interfaces
+import grokcore.site.interfaces
 import zope.location.location
 
 from zope import interface
 from zope.schema.interfaces import WrongType
 from grokcore.view.util import url
+from grokcore.site.util import getApplication
 
 
 def safely_locate_maybe(obj, parent, name):
-    """Set an object's __parent__ (and __name__) if the object's
-    __parent__ attribute doesn't exist yet or is None.
+    """Set an object's ``__parent__`` (and ``__name__``) if the object's
+    ``__parent__`` attribute doesn't exist yet or is ``None``.
 
-    If the object provides ILocation, __parent__ and __name__ will be
-    set directly.  A location proxy will be returned otherwise.
+    If the object provides ``ILocation``, ``__parent__`` and
+    ``__name__`` will be set directly.  A location proxy will be
+    returned otherwise.
     """
     if getattr(obj, '__parent__', None) is not None:
         return obj
@@ -46,28 +48,10 @@ def applySkin(request, skin, skin_type):
     interface.directlyProvides(request, *ifaces)
 
 
-def getApplication():
-    """Return the nearest enclosing `grok.Application`.
-
-    Raises ValueError if no Application can be found.
-    """
-    site = grok.getSite()
-    if grok.interfaces.IApplication.providedBy(site):
-        return site
-    # Another sub-site is within the application. Walk up the object
-    # tree until we get to the an application.
-    obj = site
-    while obj is not None:
-        if isinstance(obj, grok.Application):
-            return obj
-        obj = obj.__parent__
-    raise ValueError("No application found.")
-
-
 def application_url(request, obj, name=None, data={}):
-    """Return the URL of the nearest enclosing `grok.Application`.
+    """Return the URL of the nearest enclosing :class:`grok.Application`.
 
-    Raises ValueError if no Application can be found.
+    Raises :exc:`ValueError` if no application can be found.
     """
     return url(request, getApplication(), name, data)
 
@@ -77,7 +61,7 @@ def create_application(factory, container, name):
     the application lifecycle.
     """
     # Check the factory.
-    if not grok.interfaces.IApplication.implementedBy(factory):
+    if not grokcore.site.interfaces.IApplication.implementedBy(factory):
         raise WrongType(factory)
 
     # Check the availability of the name in the container.
